@@ -3,8 +3,8 @@ import types
 import typing
 
 from je_api_testka.requests_wrapper.request_method import test_api_method
-from je_api_testka.utils.exception.exception_tag import executor_data_error, executor_list_error
 from je_api_testka.utils.exception.exception_tag import add_command_exception_tag
+from je_api_testka.utils.exception.exception_tag import executor_data_error, executor_list_error
 from je_api_testka.utils.exception.exceptions import APITesterExecuteException, APIAddCommandException
 from je_api_testka.utils.html_report.html_report_generate import generate_html
 from je_api_testka.utils.json.json_file.json_file import read_action_json
@@ -40,13 +40,13 @@ class Executor(object):
         for loop and use execute_event function to execute
         :return: recode string, response as list
         """
-        if type(action_list) is dict:
+        if isinstance(action_list, dict):
             action_list: list = action_list.get("api_testka", None)
             if action_list is None:
                 raise APITesterExecuteException(executor_list_error)
         execute_record_dict = dict()
         try:
-            if len(action_list) > 0 or type(action_list) is not list:
+            if len(action_list) > 0 or isinstance(action_list, list) is False:
                 pass
             else:
                 raise APITesterExecuteException(executor_list_error)
